summaryrefslogtreecommitdiff
path: root/src/autoslope.h
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
committerrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
commit3b798599b63067c2e92aa49906ea66a07ae8de44 (patch)
tree69fb7ae1d9bdadb9e7386cb70b0a26621ad9b57f /src/autoslope.h
parentcc1e761edab14f8264dba44d09f7272d931bdd93 (diff)
downloadopenttd-3b798599b63067c2e92aa49906ea66a07ae8de44.tar.xz
(svn r14421) -Codechange: rename all player variables/types to company *or* client so it is immediatelly clear which one you are working with.
Diffstat (limited to 'src/autoslope.h')
-rw-r--r--src/autoslope.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/autoslope.h b/src/autoslope.h
index 9b5766c09..b5ae320f0 100644
--- a/src/autoslope.h
+++ b/src/autoslope.h
@@ -30,17 +30,17 @@ static inline bool AutoslopeCheckForEntranceEdge(TileIndex tile, uint z_new, Slo
}
/**
* Tests if autoslope is enabled for _current_player.
*
* Autoslope is disabled for town/industry construction and old ai players.
*
* @return true iff autoslope is enabled.
*/
static inline bool AutoslopeEnabled()
{
return (_settings_game.construction.autoslope &&
- ((_current_player < MAX_PLAYERS && !_is_old_ai_player) ||
- (_current_player == OWNER_NONE && _game_mode == GM_EDITOR)));
+ ((_current_company < MAX_COMPANIES && !_is_old_ai_company) ||
+ (_current_company == OWNER_NONE && _game_mode == GM_EDITOR)));
}
#endif /* AUTOSLOPE_H */
@@ -30,17 +30,17 @@ static inline bool AutoslopeCheckForEntranceEdge(TileIndex tile, uint z_new, Slo
}
/**
- * Tests if autoslope is enabled for _current_player.
+ * Tests if autoslope is enabled for _current_company.
*
@@ -30,17 +30,17 @@ static inline bool AutoslopeCheckForEntranceEdge(TileIndex tile, uint z_new, Slo
*
- * Autoslope is disabled for town/industry construction and old ai players.
+ * Autoslope is disabled for town/industry construction and old ai companies.
*
* @return true iff autoslope is enabled.